#ifndef XINEENGINE_H_
#define XINEENGINE_H_

#include <pthread.h>
#include <sigc++/trackable.h>
#include <xine.h>
#include <msp/graphics/window.h>

class XineStream;

class XineEngine: public sigc::trackable
{
private:
	Msp::Graphics::Window &window;
	xine_t *engine;
	xine_audio_port_t *audio_driver;
	x11_visual_t visual;
	xine_video_port_t *video_driver;
	Msp::Graphics::Window::Event *pending_expose;
	std::list<XineStream *> streams;

public:
	XineEngine(Msp::Graphics::Window &);
	~XineEngine();

	xine_t *get_engine() { return engine; }
	xine_audio_port_t *get_audio_driver() { return audio_driver; }
	xine_video_port_t *get_video_driver() { return video_driver; }

	void add_stream(XineStream &);
	void remove_stream(XineStream &);

	void tick();

private:
	void window_exposed(unsigned, unsigned, unsigned, unsigned, const Msp::Graphics::Window::Event &);

	static void dest_size_cb(void *, int, int, double, int *, int *, double *);
	static void frame_output_cb(void *, int, int, double, int *, int *, int *, int *, double *, int *, int *);
};

#endif
